@@ -1,9 +1,9 @@
-;;; -*- mode: Emacs-Lisp; coding: euc-japan -*-
+;;; -*- mode: Emacs-Lisp; coding: utf-8 -*-
 
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>,
 ;;          TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 ;; Created: 2000/05/01
-;; Revised: 2005-10-28 08:15:30
+;; Revised: $Date$
 
 
 ;;; Comments:
@@ -14,38 +14,38 @@
 
 ;;; About Backend:
 
-;; Υ饤֥ϡºݤ˥եХåɤƤӽФ
-;; Ȥˤäư롣ХåɤϡʲΤ褦ʥ᥽åɤ󶡤
-;; ȤԤƤ롣
+;; このライブラリは、実際にファイルを操作するバックエンドを呼び出すこ
+;; とによって動作する。バックエンドは、以下のようなメソッドを提供する
+;; ことが期待されている。
 ;;
 ;;     (mhc-foo/init)
-;;          ͥåȥξ֤˰¸ʤԤؿ
+;;          ネットワークの状態に依存しない初期化処理を行う関数
 ;;
 ;;     (mhc-foo/exit)
-;;          ͥåȥξ֤˰¸ʤλԤؿ
+;;          ネットワークの状態に依存しない終了処理を行う関数
 ;;
 ;;     (mhc-foo/open &optional OFFLINE)
-;;          ͥåȥξ֤˰¸Ԥؿ
+;;          ネットワークの状態に依存する初期化処理を行う関数
 ;;
 ;;     (mhc-foo/close &optional OFFLINE)
-;;          ͥåȥξ֤˰¸뽪λԤؿ
+;;          ネットワークの状態に依存する終了処理を行う関数
 ;;
 ;;     (mhc-foo/sync)
-;;	    塼եƱؿ
+;;          スケジュールファイルの同期を取る関数
 ;;
 ;;     (mhc-foo/add FILENAME &optional OFFLINE)
-;;	    եɲäΤؿ
-;;          (եμΤɲä줿˸ƤӽФ)
+;;          ファイルを追加を通知する関数
+;;          (ファイルの実体は追加された後に呼び出される)
 ;;
 ;;     (mhc-foo/modify FILENAME &optional  OFFLINE)
-;;	    եѹΤؿ
-;;          (եμΤѹ줿˸ƤӽФ)
+;;          ファイルの変更を通知する関数
+;;          (ファイルの実体が変更された後に呼び出される)
 ;;
 ;;     (mhc-foo/remove FILENAME &optional OFFLINE)
-;;	    եؿ
-;;          (եμΤ *줺* ƤӽФ)
+;;          ファイルを削除する関数
+;;          (ファイルの実体は *削除されずに* 呼び出される)
 ;;
-;; Υ᥽åɤŬڤ˰ʲΤ褦դä롣
+;; これらのメソッドを適切に定義し、更に以下のような宣言を付け加える。
 ;;
 ;;     (provide 'mhc-foo)
 ;;     (put 'mhc-foo 'init   'mhc-foo/init)
@@ -57,31 +57,31 @@
 ;;     (put 'mhc-foo 'modify 'mhc-foo/modify)
 ;;     (put 'mhc-foo 'remove 'mhc-foo/remove)
 ;;
-;; ᥽åɤδؿ̾Ǥդ֤ȤǤ롣
+;; メソッドの関数名は任意に選ぶことができる。
 ;;
-;; ޤ᥽åɤϾά뤳ȤǤ롣ά줿᥽åɤϡ
-;; ؿ mhc-file/true ˤäִ졢νϾΤȸ
-;; ʤ롣
+;; また、メソッドの定義は省略することができる。省略されたメソッドは、
+;; 関数 mhc-file/true によって置換され、その処理は常に成功したものと見
+;; なされる。
 
 
 ;;; Definition
 (require 'mhc-compat)
 (require 'mhc-vars)
 
+;;; Code:
 
 ;;; Global Variables
 (defcustom mhc-file-method 'mhc-sync
   "*Variable to specify the method to control schdule files."
   :group 'mhc
   :type '(radio (const :tag "Backup and remove" mhc-sync)
-		(const :tag "CVS" mhc-cvs)
-		(symbol :tag "Other")))
+                (symbol :tag "Other")))
 
 (defcustom mhc-file-sync-enable-offline nil
   "*If non-nil, enable mhc-file-sync when status is offline."
   :group 'mhc
   :type '(radio (const :tag "Disable when offline" nil)
-		(const :tag "Enable when offline" t)))
+                (const :tag "Enable when offline" t)))
 
 ;;; Internal Variables
 (defvar mhc-file/offline (not mhc-default-network-status)
@@ -99,17 +99,17 @@
 ;; To suprress byte compile warnings.
 (eval-when-compile
   (mapcar (lambda (s)
-	    (let ((f (intern (concat "mhc-file/" (symbol-name s)))))
-	      (or (fboundp f) (fset f 'mhc-file/true))))
-	  mhc-file/backend-method-list))
+            (let ((f (intern (concat "mhc-file/" (symbol-name s)))))
+              (or (fboundp f) (fset f 'mhc-file/true))))
+          mhc-file/backend-method-list))
 
 (defun mhc-file-setup (&optional method)
   "Initialize backend to manipulate files."
   (require (or method mhc-file-method))
-  (mapcar (lambda (s)
-	    (fset (intern (concat "mhc-file/" (symbol-name s)))
-		  (or (get mhc-file-method s) 'mhc-file/true)))
-	  mhc-file/backend-method-list)
+  (mapc (lambda (s)
+          (fset (intern (concat "mhc-file/" (symbol-name s)))
+                (or (get mhc-file-method s) 'mhc-file/true)))
+        mhc-file/backend-method-list)
   (and (mhc-file/init)
        (mhc-file/open mhc-file/offline)))
 
@@ -130,23 +130,23 @@
   "Strings to describe MHC network status."
   :group 'mhc
   :type '(choice
-	  (const :tag "Long format" (" mhc[offline]" . " mhc[ONLINE]"))
-	  (const :tag "Short format" (" Mhc" . " MHC"))
-	  (cons :tag "User definition"
-		(string :tag "String for offline")
-		(string :tag "String for online")))
+          (const :tag "Long format" (" mhc[offline]" . " mhc[ONLINE]"))
+          (const :tag "Short format" (" Mhc" . " MHC"))
+          (cons :tag "User definition"
+                (string :tag "String for offline")
+                (string :tag "String for online")))
   :set (lambda (symbol value)
-	 (set-default symbol value)
-	 (if (assq 'mhc-mode minor-mode-alist)
-	     (setcdr (assq 'mhc-mode minor-mode-alist) (list (mhc-file-line-status))))
-	 (force-mode-line-update)))
+         (set-default symbol value)
+         (if (assq 'mhc-mode minor-mode-alist)
+             (setcdr (assq 'mhc-mode minor-mode-alist) (list (mhc-file-line-status))))
+         (force-mode-line-update)))
 
 (defun mhc-file-line-status ()
   "Return status string for mode line."
   (if mhc-show-network-status
       (if mhc-file/offline
-	  (car mhc-file-line-status-strings)
-	(cdr mhc-file-line-status-strings))))
+          (car mhc-file-line-status-strings)
+        (cdr mhc-file-line-status-strings))))
 
 (defun mhc-file-toggle-offline (&optional full set-to no-sync)
   "*Toggle line status of file manipulation backend."
@@ -154,14 +154,14 @@
   (let ((previous mhc-file/offline))
     (setq mhc-file/offline set-to)
     (if (assq 'mhc-mode minor-mode-alist)
-	(setcdr (assq 'mhc-mode minor-mode-alist)
-		(list (mhc-file-line-status))))
+        (setcdr (assq 'mhc-mode minor-mode-alist)
+                (list (mhc-file-line-status))))
     (if mhc-file/offline
-	(message "mhc-file is offline.")
+        (message "mhc-file is offline.")
       (if (and (not no-sync)
-	       previous
-	       (y-or-n-p "Sync schedule files right now ? "))
-	  (mhc-file-sync full))
+               previous
+               (y-or-n-p "Sync schedule files right now ? "))
+          (mhc-file-sync full))
       (message "mhc-file is online."))))
 
 
@@ -180,11 +180,11 @@
   (if (file-directory-p dirname)
       t
     (if (mhc-file-make-directory
-	 (directory-file-name (file-name-directory (directory-file-name dirname))))
-	(progn
-	  (make-directory (directory-file-name dirname))
-	  (mhc-file-add (file-name-as-directory dirname))
-	  t))))
+         (directory-file-name (file-name-directory (directory-file-name dirname))))
+        (progn
+          (make-directory (directory-file-name dirname))
+          (mhc-file-add (file-name-as-directory dirname))
+          t))))
 
 
 
@@ -198,7 +198,7 @@
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -207,7 +207,7 @@
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS''
 ;; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 ;; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
@@ -221,4 +221,4 @@
 ;; ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 ;; OF THE POSSIBILITY OF SUCH DAMAGE.
 
-;;; mhc-file.el ends here.
+;;; mhc-file.el ends here
